OFFER_ID = "OfferID"
TS_DIALOGUE_ID = "TSDialogueID"

OFFER_AUTHOR_ID = "UserID"
AUTHOR_ID = "AuthorUserID"

OFFER_QUOTA = "OfferQuota"
AUTHOR_QUOTA = "AuthorQuota"

QUOTA_APPROACHED_NOTIFICATION_SENT = "NotificationQuotaApproachedSent"
QUOTA_EXHAUSTED_NOTIFICATION_SENT = "NotificationQuotaExhaustedSent"

NUM_CALLS = "NumCalls"
CALLS_LAST_PERIOD = "CallsLastPeriod"
ROW_KEY = "RowKey"

PARTITION_KEY = "PartitionKey"
HANDLER_DATA = "HandlerData"
BUDDY_GENERATOR_DATA = "BuddyGeneratorData"
USER_RATES = "UserRates"
